Crate codex_app_server_protocol

Crate codex_app_server_protocol 

Structs

AccountLoginCompletedNotification
AccountRateLimitsUpdatedNotification
AccountUpdatedNotification
AddConversationListenerParams
AddConversationSubscriptionResponse
AgentMessageDeltaNotification
ApplyPatchApprovalParams
ApplyPatchApprovalResponse
ArchiveConversationParams
ArchiveConversationResponse
AuthStatusChangeNotification
Deprecated notification. Use AccountUpdatedNotification instead.
CancelLoginAccountParams
CancelLoginAccountResponse
CancelLoginChatGptParams
CancelLoginChatGptResponse
ClientInfo
CommandExecutionOutputDeltaNotification
CommandExecutionRequestAcceptSettings
CommandExecutionRequestApprovalParams
CommandExecutionRequestApprovalResponse
ConversationGitInfo
ConversationSummary
CreditsSnapshot
ErrorNotification
ExecCommandApprovalParams
ExecCommandApprovalResponse
ExecOneOffCommandParams
ExecOneOffCommandResponse
FeedbackUploadParams
FeedbackUploadResponse
FileChangeRequestApprovalParams
FileChangeRequestApprovalResponse
FileUpdateChange
FuzzyFileSearchParams
FuzzyFileSearchResponse
FuzzyFileSearchResult
Superset of [codex_file_search::FileMatch]
GetAccountParams
GetAccountRateLimitsResponse
GetAccountResponse
GetAuthStatusParams
GetAuthStatusResponse
GetConversationSummaryResponse
GetUserAgentResponse
GetUserSavedConfigResponse
GitDiffToRemoteParams
GitDiffToRemoteResponse
GitSha
InitializeParams
InitializeResponse
InterruptConversationParams
InterruptConversationResponse
ItemCompletedNotification
ItemStartedNotification
JSONRPCError
A response to a request that indicates an error occurred.
JSONRPCErrorError
JSONRPCNotification
A notification which does not expect a response.
JSONRPCRequest
A request that expects a response.
JSONRPCResponse
A successful (non-error) response to a request.
ListConversationsParams
ListConversationsResponse
LoginApiKeyParams
LoginApiKeyResponse
LoginChatGptCompleteNotification
Deprecated in favor of AccountLoginCompletedNotification.
LoginChatGptResponse
LogoutAccountResponse
LogoutChatGptParams
LogoutChatGptResponse
McpToolCallError
McpToolCallProgressNotification
McpToolCallResult
Model
ModelListParams
ModelListResponse
NewConversationParams
NewConversationResponse
Profile
RateLimitSnapshot
RateLimitWindow
ReasoningEffortOption
ReasoningSummaryPartAddedNotification
ReasoningSummaryTextDeltaNotification
ReasoningTextDeltaNotification
RemoveConversationListenerParams
RemoveConversationSubscriptionResponse
ResumeConversationParams
ResumeConversationResponse
ReviewStartParams
SandboxCommandAssessment
SandboxSettings
SendUserMessageParams
SendUserMessageResponse
SendUserTurnParams
SendUserTurnResponse
SessionConfiguredNotification
SetDefaultModelParams
SetDefaultModelResponse
Thread
ThreadArchiveParams
ThreadArchiveResponse
ThreadCompactParams
ThreadCompactResponse
ThreadListParams
ThreadListResponse
ThreadResumeParams
There are three ways to resume a thread:
ThreadResumeResponse
ThreadStartParams
ThreadStartResponse
ThreadStartedNotification
TodoItem
Tools
Turn
TurnCompletedNotification
TurnError
TurnInterruptParams
TurnInterruptResponse
TurnStartParams
TurnStartResponse
TurnStartedNotification
Usage
UserInfoResponse
UserSavedConfig
WindowsWorldWritableWarningNotification

Enums

Account
ApprovalDecision
AskForApproval
AuthMode
ClientNotification
ClientRequest
Request from the client to the server.
CodexErrorInfo
This translation layer make sure that we expose codex error code in camel case.
CommandAction
CommandExecutionStatus
CommandRiskLevel
GetConversationSummaryParams
InputItem
JSONRPCMessage
Refers to any valid JSON-RPC object that can be decoded off the wire, or encoded to be sent.
LoginAccountParams
LoginAccountResponse
McpToolCallStatus
PatchApplyStatus
PatchChangeKind
RequestId
ReviewTarget
SandboxMode
SandboxPolicy
ServerNotification
Notification sent from the server to the client.
ServerRequest
Request initiated from the server and sent to the client.
ServerRequestPayload
ThreadItem
TurnStatus
UserInput

Constants

JSONRPC_VERSION

Functions

build_turns_from_event_msgs
Convert persisted EventMsg entries into a sequence of Turn values.
export_client_notification_schemas
export_client_param_schemas
export_client_response_schemas
export_client_responses
export_server_notification_schemas
export_server_param_schemas
export_server_response_schemas
export_server_responses
generate_json
generate_ts
generate_types

Type Aliases

Result