ClientResponse

Enum ClientResponse 

pub enum ClientResponse {
Show 129 variants Initialize { request_id: RequestId, response: InitializeResponse, }, ThreadStart { request_id: RequestId, response: ThreadStartResponse, }, ThreadResume { request_id: RequestId, response: ThreadResumeResponse, }, ThreadFork { request_id: RequestId, response: ThreadForkResponse, }, ThreadArchive { request_id: RequestId, response: ThreadArchiveResponse, }, ThreadDelete { request_id: RequestId, response: ThreadDeleteResponse, }, ThreadUnsubscribe { request_id: RequestId, response: ThreadUnsubscribeResponse, }, ThreadIncrementElicitation { request_id: RequestId, response: ThreadIncrementElicitationResponse, }, ThreadDecrementElicitation { request_id: RequestId, response: ThreadDecrementElicitationResponse, }, ThreadSetName { request_id: RequestId, response: ThreadSetNameResponse, }, ThreadGoalSet { request_id: RequestId, response: ThreadGoalSetResponse, }, ThreadGoalGet { request_id: RequestId, response: ThreadGoalGetResponse, }, ThreadGoalClear { request_id: RequestId, response: ThreadGoalClearResponse, }, ThreadMetadataUpdate { request_id: RequestId, response: ThreadMetadataUpdateResponse, }, ThreadSettingsUpdate { request_id: RequestId, response: ThreadSettingsUpdateResponse, }, ThreadMemoryModeSet { request_id: RequestId, response: ThreadMemoryModeSetResponse, }, MemoryReset { request_id: RequestId, response: MemoryResetResponse, }, ThreadUnarchive { request_id: RequestId, response: ThreadUnarchiveResponse, }, ThreadCompactStart { request_id: RequestId, response: ThreadCompactStartResponse, }, ThreadShellCommand { request_id: RequestId, response: ThreadShellCommandResponse, }, ThreadApproveGuardianDeniedAction { request_id: RequestId, response: ThreadApproveGuardianDeniedActionResponse, }, ThreadBackgroundTerminalsClean { request_id: RequestId, response: ThreadBackgroundTerminalsCleanResponse, }, ThreadBackgroundTerminalsList { request_id: RequestId, response: ThreadBackgroundTerminalsListResponse, }, ThreadBackgroundTerminalsTerminate { request_id: RequestId, response: ThreadBackgroundTerminalsTerminateResponse, }, ThreadRollback { request_id: RequestId, response: ThreadRollbackResponse, }, ThreadList { request_id: RequestId, response: ThreadListResponse, }, ThreadSearch { request_id: RequestId, response: ThreadSearchResponse, }, ThreadSearchOccurrences { request_id: RequestId, response: ThreadSearchOccurrencesResponse, }, ThreadLoadedList { request_id: RequestId, response: ThreadLoadedListResponse, }, ThreadRead { request_id: RequestId, response: ThreadReadResponse, }, ThreadTurnsList { request_id: RequestId, response: ThreadTurnsListResponse, }, ThreadItemsList { request_id: RequestId, response: ThreadItemsListResponse, }, ThreadInjectItems { request_id: RequestId, response: ThreadInjectItemsResponse, }, SkillsList { request_id: RequestId, response: SkillsListResponse, }, SkillsExtraRootsSet { request_id: RequestId, response: SkillsExtraRootsSetResponse, }, HooksList { request_id: RequestId, response: HooksListResponse, }, MarketplaceAdd { request_id: RequestId, response: MarketplaceAddResponse, }, MarketplaceRemove { request_id: RequestId, response: MarketplaceRemoveResponse, }, MarketplaceUpgrade { request_id: RequestId, response: MarketplaceUpgradeResponse, }, PluginList { request_id: RequestId, response: PluginListResponse, }, PluginInstalled { request_id: RequestId, response: PluginInstalledResponse, }, PluginRead { request_id: RequestId, response: PluginReadResponse, }, PluginSkillRead { request_id: RequestId, response: PluginSkillReadResponse, }, PluginShareSave { request_id: RequestId, response: PluginShareSaveResponse, }, PluginShareUpdateTargets { request_id: RequestId, response: PluginShareUpdateTargetsResponse, }, PluginShareList { request_id: RequestId, response: PluginShareListResponse, }, PluginShareCheckout { request_id: RequestId, response: PluginShareCheckoutResponse, }, PluginShareDelete { request_id: RequestId, response: PluginShareDeleteResponse, }, AppsRead { request_id: RequestId, response: AppsReadResponse, }, AppsList { request_id: RequestId, response: AppsListResponse, }, AppsInstalled { request_id: RequestId, response: AppsInstalledResponse, }, FsReadFile { request_id: RequestId, response: FsReadFileResponse, }, FsWriteFile { request_id: RequestId, response: FsWriteFileResponse, }, FsCreateDirectory { request_id: RequestId, response: FsCreateDirectoryResponse, }, FsGetMetadata { request_id: RequestId, response: FsGetMetadataResponse, }, FsReadDirectory { request_id: RequestId, response: FsReadDirectoryResponse, }, FsRemove { request_id: RequestId, response: FsRemoveResponse, }, FsCopy { request_id: RequestId, response: FsCopyResponse, }, FsWatch { request_id: RequestId, response: FsWatchResponse, }, FsUnwatch { request_id: RequestId, response: FsUnwatchResponse, }, SkillsConfigWrite { request_id: RequestId, response: SkillsConfigWriteResponse, }, PluginInstall { request_id: RequestId, response: PluginInstallResponse, }, PluginUninstall { request_id: RequestId, response: PluginUninstallResponse, }, TurnStart { request_id: RequestId, response: TurnStartResponse, }, TurnSteer { request_id: RequestId, response: TurnSteerResponse, }, TurnInterrupt { request_id: RequestId, response: TurnInterruptResponse, }, ThreadRealtimeStart { request_id: RequestId, response: ThreadRealtimeStartResponse, }, ThreadRealtimeAppendAudio { request_id: RequestId, response: ThreadRealtimeAppendAudioResponse, }, ThreadRealtimeAppendText { request_id: RequestId, response: ThreadRealtimeAppendTextResponse, }, ThreadRealtimeAppendSpeech { request_id: RequestId, response: ThreadRealtimeAppendSpeechResponse, }, ThreadRealtimeStop { request_id: RequestId, response: ThreadRealtimeStopResponse, }, ThreadRealtimeListVoices { request_id: RequestId, response: ThreadRealtimeListVoicesResponse, }, ReviewStart { request_id: RequestId, response: ReviewStartResponse, }, ModelList { request_id: RequestId, response: ModelListResponse, }, ModelProviderCapabilitiesRead { request_id: RequestId, response: ModelProviderCapabilitiesReadResponse, }, ExperimentalFeatureList { request_id: RequestId, response: ExperimentalFeatureListResponse, }, PermissionProfileList { request_id: RequestId, response: PermissionProfileListResponse, }, ExperimentalFeatureEnablementSet { request_id: RequestId, response: ExperimentalFeatureEnablementSetResponse, }, RemoteControlEnable { request_id: RequestId, response: RemoteControlEnableResponse, }, RemoteControlDisable { request_id: RequestId, response: RemoteControlDisableResponse, }, RemoteControlStatusRead { request_id: RequestId, response: RemoteControlStatusReadResponse, }, RemoteControlPairingStart { request_id: RequestId, response: RemoteControlPairingStartResponse, }, RemoteControlPairingStatus { request_id: RequestId, response: RemoteControlPairingStatusResponse, }, RemoteControlClientsList { request_id: RequestId, response: RemoteControlClientsListResponse, }, RemoteControlClientsRevoke { request_id: RequestId, response: RemoteControlClientsRevokeResponse, }, CollaborationModeList { request_id: RequestId, response: CollaborationModeListResponse, }, MockExperimentalMethod { request_id: RequestId, response: MockExperimentalMethodResponse, }, EnvironmentAdd { request_id: RequestId, response: EnvironmentAddResponse, }, EnvironmentInfo { request_id: RequestId, response: EnvironmentInfoResponse, }, EnvironmentStatus { request_id: RequestId, response: EnvironmentStatusResponse, }, McpServerOauthLogin { request_id: RequestId, response: McpServerOauthLoginResponse, }, McpServerRefresh { request_id: RequestId, response: McpServerRefreshResponse, }, McpServerStatusList { request_id: RequestId, response: ListMcpServerStatusResponse, }, McpResourceRead { request_id: RequestId, response: McpResourceReadResponse, }, McpServerToolCall { request_id: RequestId, response: McpServerToolCallResponse, }, WindowsSandboxSetupStart { request_id: RequestId, response: WindowsSandboxSetupStartResponse, }, WindowsSandboxReadiness { request_id: RequestId, response: WindowsSandboxReadinessResponse, }, LoginAccount { request_id: RequestId, response: LoginAccountResponse, }, CancelLoginAccount { request_id: RequestId, response: CancelLoginAccountResponse, }, LogoutAccount { request_id: RequestId, response: LogoutAccountResponse, }, GetAccountRateLimits { request_id: RequestId, response: GetAccountRateLimitsResponse, }, ConsumeAccountRateLimitResetCredit { request_id: RequestId, response: ConsumeAccountRateLimitResetCreditResponse, }, GetAccountTokenUsage { request_id: RequestId, response: GetAccountTokenUsageResponse, }, GetWorkspaceMessages { request_id: RequestId, response: GetWorkspaceMessagesResponse, }, SendAddCreditsNudgeEmail { request_id: RequestId, response: SendAddCreditsNudgeEmailResponse, }, FeedbackUpload { request_id: RequestId, response: FeedbackUploadResponse, }, OneOffCommandExec { request_id: RequestId, response: CommandExecResponse, }, CommandExecWrite { request_id: RequestId, response: CommandExecWriteResponse, }, CommandExecTerminate { request_id: RequestId, response: CommandExecTerminateResponse, }, CommandExecResize { request_id: RequestId, response: CommandExecResizeResponse, }, ProcessSpawn { request_id: RequestId, response: ProcessSpawnResponse, }, ProcessWriteStdin { request_id: RequestId, response: ProcessWriteStdinResponse, }, ProcessKill { request_id: RequestId, response: ProcessKillResponse, }, ProcessResizePty { request_id: RequestId, response: ProcessResizePtyResponse, }, ConfigRead { request_id: RequestId, response: ConfigReadResponse, }, ExternalAgentConfigDetect { request_id: RequestId, response: ExternalAgentConfigDetectResponse, }, ExternalAgentConfigImport { request_id: RequestId, response: ExternalAgentConfigImportResponse, }, ExternalAgentConfigImportHistoriesRead { request_id: RequestId, response: ExternalAgentConfigImportHistoriesReadResponse, }, ConfigValueWrite { request_id: RequestId, response: ConfigWriteResponse, }, ConfigBatchWrite { request_id: RequestId, response: ConfigWriteResponse, }, ConfigRequirementsRead { request_id: RequestId, response: ConfigRequirementsReadResponse, }, GetAccount { request_id: RequestId, response: GetAccountResponse, }, GetConversationSummary { request_id: RequestId, response: GetConversationSummaryResponse, }, GitDiffToRemote { request_id: RequestId, response: GitDiffToRemoteResponse, }, GetAuthStatus { request_id: RequestId, response: GetAuthStatusResponse, }, FuzzyFileSearch { request_id: RequestId, response: FuzzyFileSearchResponse, }, FuzzyFileSearchSessionStart { request_id: RequestId, response: FuzzyFileSearchSessionStartResponse, }, FuzzyFileSearchSessionUpdate { request_id: RequestId, response: FuzzyFileSearchSessionUpdateResponse, }, FuzzyFileSearchSessionStop { request_id: RequestId, response: FuzzyFileSearchSessionStopResponse, },
}
Typed response from the server to the client.

Variants



Initialize

Fields

request_id: RequestId


ThreadStart

NEW APIs

Fields

request_id: RequestId


ThreadResume

Fields

request_id: RequestId


ThreadFork

Fields

request_id: RequestId


ThreadArchive

Fields

request_id: RequestId


ThreadDelete

Fields

request_id: RequestId


ThreadUnsubscribe

Fields

request_id: RequestId


ThreadIncrementElicitation

Increment the thread-local out-of-band elicitation counter.

This is used by external helpers to pause timeout accounting while a user approval or other elicitation is pending outside the app-server request flow.



ThreadDecrementElicitation

Decrement the thread-local out-of-band elicitation counter.

When the count reaches zero, timeout accounting resumes for the thread.



ThreadSetName

Fields

request_id: RequestId


ThreadGoalSet

Fields

request_id: RequestId


ThreadGoalGet

Fields

request_id: RequestId


ThreadGoalClear

Fields

request_id: RequestId


ThreadMetadataUpdate

Fields

request_id: RequestId


ThreadSettingsUpdate

Fields

request_id: RequestId


ThreadMemoryModeSet

Fields

request_id: RequestId


MemoryReset

Fields

request_id: RequestId


ThreadUnarchive

Fields

request_id: RequestId


ThreadCompactStart

Fields

request_id: RequestId


ThreadShellCommand

Fields

request_id: RequestId


ThreadApproveGuardianDeniedAction



ThreadBackgroundTerminalsClean



ThreadBackgroundTerminalsList



ThreadBackgroundTerminalsTerminate



ThreadRollback

Fields

request_id: RequestId


ThreadList

Fields

request_id: RequestId


ThreadSearch

Fields

request_id: RequestId


ThreadSearchOccurrences



ThreadLoadedList

Fields

request_id: RequestId


ThreadRead

Fields

request_id: RequestId


ThreadTurnsList

Fields

request_id: RequestId


ThreadItemsList

Fields

request_id: RequestId


ThreadInjectItems

Append raw Responses API items to the thread history without starting a user turn.

Fields

request_id: RequestId


SkillsList

Fields

request_id: RequestId


SkillsExtraRootsSet

Fields

request_id: RequestId


HooksList

Fields

request_id: RequestId


MarketplaceAdd

Fields

request_id: RequestId


MarketplaceRemove

Fields

request_id: RequestId


MarketplaceUpgrade

Fields

request_id: RequestId


PluginList

Fields

request_id: RequestId


PluginInstalled

Fields

request_id: RequestId


PluginRead

Fields

request_id: RequestId


PluginSkillRead

Fields

request_id: RequestId


PluginShareSave

Fields

request_id: RequestId


PluginShareUpdateTargets



PluginShareList

Fields

request_id: RequestId


PluginShareCheckout

Fields

request_id: RequestId


PluginShareDelete

Fields

request_id: RequestId


AppsRead

Fields

request_id: RequestId


AppsList

Fields

request_id: RequestId


AppsInstalled

Fields

request_id: RequestId


FsReadFile

Fields

request_id: RequestId


FsWriteFile

Fields

request_id: RequestId


FsCreateDirectory

Fields

request_id: RequestId


FsGetMetadata

Fields

request_id: RequestId


FsReadDirectory

Fields

request_id: RequestId


FsRemove

Fields

request_id: RequestId


FsCopy

Fields

request_id: RequestId


FsWatch

Fields

request_id: RequestId


FsUnwatch

Fields

request_id: RequestId


SkillsConfigWrite

Fields

request_id: RequestId


PluginInstall

Fields

request_id: RequestId


PluginUninstall

Fields

request_id: RequestId


TurnStart

Fields

request_id: RequestId


TurnSteer

Fields

request_id: RequestId


TurnInterrupt

Fields

request_id: RequestId


ThreadRealtimeStart

Fields

request_id: RequestId


ThreadRealtimeAppendAudio



ThreadRealtimeAppendText



ThreadRealtimeAppendSpeech



ThreadRealtimeStop

Fields

request_id: RequestId


ThreadRealtimeListVoices



ReviewStart

Fields

request_id: RequestId


ModelList

Fields

request_id: RequestId


ModelProviderCapabilitiesRead



ExperimentalFeatureList



PermissionProfileList

Fields

request_id: RequestId


ExperimentalFeatureEnablementSet



RemoteControlEnable

Fields

request_id: RequestId


RemoteControlDisable

Fields

request_id: RequestId


RemoteControlStatusRead



RemoteControlPairingStart



RemoteControlPairingStatus



RemoteControlClientsList



RemoteControlClientsRevoke



CollaborationModeList

Lists collaboration mode presets.

Fields

request_id: RequestId


MockExperimentalMethod

Test-only method used to validate experimental gating.



EnvironmentAdd

Adds or replaces a remote environment by id for later selection.

Fields

request_id: RequestId


EnvironmentInfo

Reads information from a configured execution environment.

Fields

request_id: RequestId


EnvironmentStatus

Reads the current status of a configured execution environment.

Fields

request_id: RequestId


McpServerOauthLogin

Fields

request_id: RequestId


McpServerRefresh

Fields

request_id: RequestId


McpServerStatusList

Fields

request_id: RequestId


McpResourceRead

Fields

request_id: RequestId


McpServerToolCall

Fields

request_id: RequestId


WindowsSandboxSetupStart



WindowsSandboxReadiness



LoginAccount

Fields

request_id: RequestId


CancelLoginAccount

Fields

request_id: RequestId


LogoutAccount

Fields

request_id: RequestId


GetAccountRateLimits

Fields

request_id: RequestId


ConsumeAccountRateLimitResetCredit



GetAccountTokenUsage

Fields

request_id: RequestId


GetWorkspaceMessages

Fields

request_id: RequestId


SendAddCreditsNudgeEmail



FeedbackUpload

Fields

request_id: RequestId


OneOffCommandExec

Execute a standalone command (argv vector) under the server’s sandbox.

Fields

request_id: RequestId


CommandExecWrite

Write stdin bytes to a running command/exec session or close stdin.

Fields

request_id: RequestId


CommandExecTerminate

Terminate a running command/exec session by client-supplied processId.

Fields

request_id: RequestId


CommandExecResize

Resize a running PTY-backed command/exec session by client-supplied processId.

Fields

request_id: RequestId


ProcessSpawn

Spawn a standalone process (argv vector) without a Codex sandbox.

Fields

request_id: RequestId


ProcessWriteStdin

Write stdin bytes to a running process/spawn session or close stdin.

Fields

request_id: RequestId


ProcessKill

Terminate a running process/spawn session by client-supplied processHandle.

Fields

request_id: RequestId


ProcessResizePty

Resize a running PTY-backed process/spawn session by client-supplied processHandle.

Fields

request_id: RequestId


ConfigRead

Fields

request_id: RequestId


ExternalAgentConfigDetect



ExternalAgentConfigImport



ExternalAgentConfigImportHistoriesRead



ConfigValueWrite

Fields

request_id: RequestId


ConfigBatchWrite

Fields

request_id: RequestId


ConfigRequirementsRead



GetAccount

Fields

request_id: RequestId


GetConversationSummary

DEPRECATED APIs below



GitDiffToRemote

Fields

request_id: RequestId


GetAuthStatus

DEPRECATED in favor of GetAccount

Fields

request_id: RequestId


FuzzyFileSearch

Fields

request_id: RequestId


FuzzyFileSearchSessionStart



FuzzyFileSearchSessionUpdate



FuzzyFileSearchSessionStop

Implementations