pub enum ConfigLayerSource {
Mdm {
domain: String,
key: String,
},
System {
file: AbsolutePathBuf,
},
EnterpriseManaged {
id: String,
name: String,
},
User {
file: AbsolutePathBuf,
profile: Option<String>,
},
Project {
dot_codex_folder: AbsolutePathBuf,
},
SessionFlags,
LegacyManagedConfigTomlFromFile {
file: AbsolutePathBuf,
},
LegacyManagedConfigTomlFromMdm,
}Variants
Mdm
Managed preferences layer delivered by MDM (macOS only).
System
Managed config layer from a file (usually managed_config.toml).
Fields
file: AbsolutePathBufThis is the path to the system config.toml file, though it is not guaranteed to exist.
EnterpriseManaged
Enterprise-managed config layer delivered by the cloud config bundle.
Fields
User
User config layer from $CODEX_HOME/config.toml. This layer is special in that it is expected to be:
- writable by the user
- generally outside the workspace directory
Fields
file: AbsolutePathBufThis is the path to the user’s config.toml file, though it is not guaranteed to exist.
Project
Path to a .codex/ folder within a project. There could be multiple of
these between cwd and the project/repo root.
Fields
dot_codex_folder: AbsolutePathBufSessionFlags
Session-layer overrides supplied via -c/--config.
LegacyManagedConfigTomlFromFile
managed_config.toml was designed to be a config that was loaded
as the last layer on top of everything else. This scheme did not quite
work out as intended, but we keep this variant as a “best effort” while
we phase out managed_config.toml in favor of requirements.toml.
Fields
file: AbsolutePathBufLegacyManagedConfigTomlFromMdm
Implementations
Sourceimpl ConfigLayerSource
impl ConfigLayerSource
Sourcepub fn precedence(&self) -> i16
pub fn precedence(&self) -> i16
A settings from a layer with a higher precedence will override a setting from a layer with a lower precedence.