pub enum ServerRequest {
CommandExecutionRequestApproval {
request_id: RequestId,
params: CommandExecutionRequestApprovalParams,
},
FileChangeRequestApproval {
request_id: RequestId,
params: FileChangeRequestApprovalParams,
},
ToolRequestUserInput {
request_id: RequestId,
params: ToolRequestUserInputParams,
},
McpServerElicitationRequest {
request_id: RequestId,
params: McpServerElicitationRequestParams,
},
PermissionsRequestApproval {
request_id: RequestId,
params: PermissionsRequestApprovalParams,
},
DynamicToolCall {
request_id: RequestId,
params: DynamicToolCallParams,
},
ChatgptAuthTokensRefresh {
request_id: RequestId,
params: ChatgptAuthTokensRefreshParams,
},
AttestationGenerate {
request_id: RequestId,
params: AttestationGenerateParams,
},
CurrentTimeRead {
request_id: RequestId,
params: CurrentTimeReadParams,
},
ApplyPatchApproval {
request_id: RequestId,
params: ApplyPatchApprovalParams,
},
ExecCommandApproval {
request_id: RequestId,
params: ExecCommandApprovalParams,
},
}Expand description
Request initiated from the server and sent to the client.
Variants
CommandExecutionRequestApproval
NEW APIs Sent when approval is requested for a specific command execution. This request is used for Turns started via turn/start.
FileChangeRequestApproval
Sent when approval is requested for a specific file change. This request is used for Turns started via turn/start.
ToolRequestUserInput
EXPERIMENTAL - Request input from the user for a tool call.
McpServerElicitationRequest
Request input for an MCP server elicitation.
PermissionsRequestApproval
Request approval for additional permissions from the user.
DynamicToolCall
Execute a dynamic tool call on the client.
ChatgptAuthTokensRefresh
AttestationGenerate
Generate a fresh upstream attestation result on demand.
CurrentTimeRead
Read the current time from an external clock owned by the client.
ApplyPatchApproval
DEPRECATED APIs below Request to approve a patch. This request is used for Turns started via the legacy APIs (i.e. SendUserTurn, SendUserMessage).
ExecCommandApproval
Request to exec a command. This request is used for Turns started via the legacy APIs (i.e. SendUserTurn, SendUserMessage).
Implementations
Sourceimpl ServerRequest
impl ServerRequest
pub fn id(&self) -> &RequestId
pub fn response_from_result(&self, result: Result) -> Result<ServerResponse>