pub enum ServerResponse {
CommandExecutionRequestApproval {
request_id: RequestId,
response: CommandExecutionRequestApprovalResponse,
},
FileChangeRequestApproval {
request_id: RequestId,
response: FileChangeRequestApprovalResponse,
},
ToolRequestUserInput {
request_id: RequestId,
response: ToolRequestUserInputResponse,
},
McpServerElicitationRequest {
request_id: RequestId,
response: McpServerElicitationRequestResponse,
},
PermissionsRequestApproval {
request_id: RequestId,
response: PermissionsRequestApprovalResponse,
},
DynamicToolCall {
request_id: RequestId,
response: DynamicToolCallResponse,
},
ChatgptAuthTokensRefresh {
request_id: RequestId,
response: ChatgptAuthTokensRefreshResponse,
},
AttestationGenerate {
request_id: RequestId,
response: AttestationGenerateResponse,
},
CurrentTimeRead {
request_id: RequestId,
response: CurrentTimeReadResponse,
},
ApplyPatchApproval {
request_id: RequestId,
response: ApplyPatchApprovalResponse,
},
ExecCommandApproval {
request_id: RequestId,
response: ExecCommandApprovalResponse,
},
}Expand description
Typed response from the client to the server.
Variants
CommandExecutionRequestApproval
NEW APIs Sent when approval is requested for a specific command execution. This request is used for Turns started via turn/start.
FileChangeRequestApproval
Sent when approval is requested for a specific file change. This request is used for Turns started via turn/start.
ToolRequestUserInput
EXPERIMENTAL - Request input from the user for a tool call.
McpServerElicitationRequest
Request input for an MCP server elicitation.
PermissionsRequestApproval
Request approval for additional permissions from the user.
DynamicToolCall
Execute a dynamic tool call on the client.
ChatgptAuthTokensRefresh
AttestationGenerate
Generate a fresh upstream attestation result on demand.
CurrentTimeRead
Read the current time from an external clock owned by the client.
ApplyPatchApproval
DEPRECATED APIs below Request to approve a patch. This request is used for Turns started via the legacy APIs (i.e. SendUserTurn, SendUserMessage).
ExecCommandApproval
Request to exec a command. This request is used for Turns started via the legacy APIs (i.e. SendUserTurn, SendUserMessage).
Implementations