pub enum ThreadItem {
UserMessage {
id: String,
content: Vec<UserInput>,
},
AgentMessage {
id: String,
text: String,
},
Reasoning {
id: String,
summary: Vec<String>,
content: Vec<String>,
},
CommandExecution {
id: String,
command: String,
cwd: PathBuf,
status: CommandExecutionStatus,
command_actions: Vec<CommandAction>,
aggregated_output: Option<String>,
exit_code: Option<i32>,
duration_ms: Option<i64>,
},
FileChange {
id: String,
changes: Vec<FileUpdateChange>,
status: PatchApplyStatus,
},
McpToolCall {
id: String,
server: String,
tool: String,
status: McpToolCallStatus,
arguments: Value,
result: Option<McpToolCallResult>,
error: Option<McpToolCallError>,
},
WebSearch {
id: String,
query: String,
},
TodoList {
id: String,
items: Vec<TodoItem>,
},
ImageView {
id: String,
path: String,
},
CodeReview {
id: String,
review: String,
},
}Variants
UserMessage
AgentMessage
Reasoning
CommandExecution
Fields

status: CommandExecutionStatus
command_actions: Vec<CommandAction>A best-effort parsing of the command to understand the action(s) it will perform. This returns a list of CommandAction objects because a single shell command may be composed of many commands piped together.
FileChange
McpToolCall
WebSearch
TodoList
ImageView
CodeReview