Module rpc

Module rpc 

We do not do true JSON-RPC 2.0, as we neither send nor expect the “jsonrpc”: “2.0” field.

Structs

JSONRPCError
A response to a request that indicates an error occurred.
JSONRPCErrorError
JSONRPCNotification
A notification which does not expect a response.
JSONRPCRequest
A request that expects a response.
JSONRPCResponse
A successful (non-error) response to a request.

Enums

JSONRPCMessage
Refers to any valid JSON-RPC object that can be decoded off the wire, or encoded to be sent.
RequestId

Constants

JSONRPC_VERSION

Type Aliases

Result