pub struct Thread {Show 24 fields
pub id: String,
pub extra: Option<ThreadExtra>,
pub session_id: String,
pub forked_from_id: Option<String>,
pub parent_thread_id: Option<String>,
pub preview: String,
pub ephemeral: bool,
pub history_mode: ThreadHistoryMode,
pub model_provider: String,
pub created_at: i64,
pub updated_at: i64,
pub recency_at: Option<i64>,
pub status: ThreadStatus,
pub path: Option<PathBuf>,
pub cwd: AbsolutePathBuf,
pub cli_version: String,
pub source: SessionSource,
pub can_accept_direct_input: Option<bool>,
pub thread_source: Option<ThreadSource>,
pub agent_nickname: Option<String>,
pub agent_role: Option<String>,
pub git_info: Option<GitInfo>,
pub name: Option<String>,
pub turns: Vec<Turn>,
}Fields
id: StringIdentifier for this thread. Codex-generated thread IDs are UUIDv7.
extra: Option<ThreadExtra>Optional implementation-specific thread data.
session_id: StringSession id shared by threads that belong to the same session tree.
forked_from_id: Option<String>Source thread id when this thread was created by forking another thread.
parent_thread_id: Option<String>The ID of the parent thread. This will only be set if this thread is a subagent.
preview: StringUsually the first user message in the thread, if available.
ephemeral: boolWhether the thread is ephemeral and should not be materialized on disk.
history_mode: ThreadHistoryModePersisted thread history contract selected when this thread was created.
model_provider: StringModel provider used for this thread (for example, ‘openai’).
created_at: i64Unix timestamp (in seconds) when the thread was created.
updated_at: i64Unix timestamp (in seconds) when the thread was last updated.
recency_at: Option<i64>Unix timestamp (in seconds) used for thread recency ordering.
status: ThreadStatusCurrent runtime status for the thread.
path: Option<PathBuf>[UNSTABLE] Path to the thread on disk.
cwd: AbsolutePathBufWorking directory captured for the thread.
cli_version: StringVersion of the CLI that created the thread.
source: SessionSourceOrigin of the thread (CLI, VSCode, codex exec, codex app-server, etc.).
can_accept_direct_input: Option<bool>Whether the app server accepts direct turn input for this loaded thread.
None means the capability is unavailable, such as for an unloaded stored thread.
thread_source: Option<ThreadSource>Optional analytics source classification for this thread.
agent_nickname: Option<String>Optional random unique nickname assigned to an AgentControl-spawned sub-agent.
agent_role: Option<String>Optional role (agent_role) assigned to an AgentControl-spawned sub-agent.
git_info: Option<GitInfo>Optional Git metadata captured when the thread was created.
name: Option<String>Optional user-facing thread title.
turns: Vec<Turn>Only populated on thread/resume, thread/rollback, thread/fork, and thread/read
(when includeTurns is true) responses.
For all other responses and notifications returning a Thread,
the turns field will be an empty list.