pub struct ThreadResumeParams {
pub thread_id: String,
pub history: Option<Vec<ResponseItem>>,
pub path: Option<PathBuf>,
pub model: Option<String>,
pub model_provider: Option<String>,
pub cwd: Option<String>,
pub approval_policy: Option<AskForApproval>,
pub sandbox: Option<SandboxMode>,
pub config: Option<HashMap<String, Value>>,
pub base_instructions: Option<String>,
pub developer_instructions: Option<String>,
}Expand description
There are three ways to resume a thread:
- By thread_id: load the thread from disk by thread_id and resume it.
- By history: instantiate the thread from memory and resume it.
- By path: load the thread from disk by path and resume it.
The precedence is: history > path > thread_id. If using history or path, the thread_id param will be ignored.
Prefer using thread_id whenever possible.
Fields
thread_id: Stringhistory: Option<Vec<ResponseItem>>[UNSTABLE] FOR CODEX CLOUD - DO NOT USE. If specified, the thread will be resumed with the provided history instead of loaded from disk.
path: Option<PathBuf>[UNSTABLE] Specify the rollout path to resume from. If specified, the thread_id param will be ignored.
model: Option<String>Configuration overrides for the resumed thread, if any.
model_provider: Option<String>cwd: Option<String>approval_policy: Option<AskForApproval>sandbox: Option<SandboxMode>config: Option<HashMap<String, Value>>base_instructions: Option<String>developer_instructions: Option<String>Trait Implementations
Sourceimpl Clone for ThreadResumeParams
impl Clone for ThreadResumeParams
Sourcefn clone(&self) -> ThreadResumeParams
fn clone(&self) -> ThreadResumeParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadResumeParams
impl Debug for ThreadResumeParams
Sourceimpl Default for ThreadResumeParams
impl Default for ThreadResumeParams
Sourcefn default() -> ThreadResumeParams
fn default() -> ThreadResumeParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ThreadResumeParams
impl<'de> Deserialize<'de> for ThreadResumeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ThreadResumeParams
impl JsonSchema for ThreadResumeParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ThreadResumeParams
impl PartialEq for ThreadResumeParams
Sourcefn eq(&self, other: &ThreadResumeParams) -> bool
fn eq(&self, other: &ThreadResumeParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ThreadResumeParams
impl Serialize for ThreadResumeParams
impl StructuralPartialEq for ThreadResumeParams
Sourceimpl TS for ThreadResumeParams
impl TS for ThreadResumeParams
Sourcetype WithoutGenerics = ThreadResumeParams
type WithoutGenerics = ThreadResumeParams
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = ThreadResumeParams
type OptionInnerType = ThreadResumeParams
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,