pub struct ThreadStartParams {Show 25 fields
pub model: Option<String>,
pub model_provider: Option<String>,
pub allow_provider_model_fallback: bool,
pub service_tier: Option<Option<String>>,
pub cwd: Option<String>,
pub runtime_workspace_roots: Option<Vec<AbsolutePathBuf>>,
pub approval_policy: Option<AskForApproval>,
pub approvals_reviewer: Option<ApprovalsReviewer>,
pub sandbox: Option<SandboxMode>,
pub permissions: Option<String>,
pub config: Option<HashMap<String, Value>>,
pub service_name: Option<String>,
pub base_instructions: Option<String>,
pub developer_instructions: Option<String>,
pub personality: Option<Personality>,
pub multi_agent_mode: Option<MultiAgentMode>,
pub ephemeral: Option<bool>,
pub history_mode: Option<ThreadHistoryMode>,
pub session_start_source: Option<ThreadStartSource>,
pub thread_source: Option<ThreadSource>,
pub environments: Option<Vec<TurnEnvironmentParams>>,
pub dynamic_tools: Option<Vec<DynamicToolSpec>>,
pub selected_capability_roots: Option<Vec<SelectedCapabilityRoot>>,
pub mock_experimental_field: Option<String>,
pub experimental_raw_events: bool,
}Fields
model: Option<String>model_provider: Option<String>allow_provider_model_fallback: boolAllow a provider with an authoritative static model catalog to replace an unavailable requested model with its default.
service_tier: Option<Option<String>>cwd: Option<String>runtime_workspace_roots: Option<Vec<AbsolutePathBuf>>Replace the thread’s runtime workspace roots. Paths must be absolute.
approval_policy: Option<AskForApproval>approvals_reviewer: Option<ApprovalsReviewer>Override where approval requests are routed for review on this thread and subsequent turns.
sandbox: Option<SandboxMode>permissions: Option<String>Named profile id for this thread. Cannot be combined with sandbox.
config: Option<HashMap<String, Value>>service_name: Option<String>base_instructions: Option<String>developer_instructions: Option<String>personality: Option<Personality>multi_agent_mode: Option<MultiAgentMode>@deprecated Ignored. Use Ultra reasoning effort for proactive multi-agent behavior.
ephemeral: Option<bool>history_mode: Option<ThreadHistoryMode>Persisted thread history contract to use for this new thread.
session_start_source: Option<ThreadStartSource>thread_source: Option<ThreadSource>Optional client-supplied analytics source classification for this thread.
environments: Option<Vec<TurnEnvironmentParams>>Optional sticky environments for this thread.
Omitted selects the default environment when environment access is enabled. Empty disables environment access for turns that do not provide a turn override. Non-empty selects the first environment as the current turn environment.
dynamic_tools: Option<Vec<DynamicToolSpec>>selected_capability_roots: Option<Vec<SelectedCapabilityRoot>>Capability roots selected for this thread by the hosting platform.
mock_experimental_field: Option<String>Test-only experimental field used to validate experimental gating and schema filtering behavior in a stable way.
experimental_raw_events: boolIf true, opt into emitting raw Responses API items on the event stream. This is for internal use only (e.g. Codex Cloud).