pub struct TurnStartParams {
pub thread_id: String,
pub input: Vec<UserInput>,
pub cwd: Option<PathBuf>,
pub approval_policy: Option<AskForApproval>,
pub sandbox_policy: Option<SandboxPolicy>,
pub model: Option<String>,
pub effort: Option<ReasoningEffort>,
pub summary: Option<ReasoningSummary>,
}Fields
thread_id: Stringinput: Vec<UserInput>cwd: Option<PathBuf>Override the working directory for this turn and subsequent turns.
approval_policy: Option<AskForApproval>Override the approval policy for this turn and subsequent turns.
sandbox_policy: Option<SandboxPolicy>Override the sandbox policy for this turn and subsequent turns.
model: Option<String>Override the model for this turn and subsequent turns.
effort: Option<ReasoningEffort>Override the reasoning effort for this turn and subsequent turns.
summary: Option<ReasoningSummary>Override the reasoning summary for this turn and subsequent turns.