pub struct TurnSteerParams {
pub thread_id: String,
pub client_user_message_id: Option<String>,
pub input: Vec<UserInput>,
pub responsesapi_client_metadata: Option<HashMap<String, String>>,
pub additional_context: Option<HashMap<String, AdditionalContextEntry>>,
pub expected_turn_id: String,
}Fields
thread_id: Stringclient_user_message_id: Option<String>input: Vec<UserInput>responsesapi_client_metadata: Option<HashMap<String, String>>Optional metadata to enrich Codex’s ResponsesAPI turn metadata.
Entries are flattened into the JSON string sent as
client_metadata["x-codex-turn-metadata"] on ResponsesAPI HTTP and websocket requests.
They are not sent as top-level ResponsesAPI client_metadata keys, and reserved keys
such as session_id, thread_id, turn_id, and window_id cannot be overridden.
additional_context: Option<HashMap<String, AdditionalContextEntry>>Optional client-provided context fragments keyed by an opaque source identifier.
expected_turn_id: StringRequired active turn id precondition. The request fails when it does not match the currently active turn.