ExperimentalApi

Trait ExperimentalApi 

pub trait ExperimentalApi {
    // Required method
    fn experimental_reason(&self) -> Option<&'static str>;
}
Marker trait for protocol types that can signal experimental usage.

Required Methods

fn experimental_reason(&self) -> Option<&'static str>

Returns a short reason identifier when an experimental method or field is used, or None when the value is entirely stable.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<K, V: ExperimentalApi, S> ExperimentalApi for HashMap<K, V, S>

Source

fn experimental_reason(&self) -> Option<&'static str>

Source

impl<K: Ord, V: ExperimentalApi> ExperimentalApi for BTreeMap<K, V>

Source

fn experimental_reason(&self) -> Option<&'static str>

Source

impl<T: ExperimentalApi> ExperimentalApi for Option<T>

Source

fn experimental_reason(&self) -> Option<&'static str>

Source

impl<T: ExperimentalApi> ExperimentalApi for Vec<T>

Source

fn experimental_reason(&self) -> Option<&'static str>

Implementors