pub enum ClientRequest {
Show 129 variants
Initialize {
request_id: RequestId,
params: InitializeParams,
},
ThreadStart {
request_id: RequestId,
params: ThreadStartParams,
},
ThreadResume {
request_id: RequestId,
params: ThreadResumeParams,
},
ThreadFork {
request_id: RequestId,
params: ThreadForkParams,
},
ThreadArchive {
request_id: RequestId,
params: ThreadArchiveParams,
},
ThreadDelete {
request_id: RequestId,
params: ThreadDeleteParams,
},
ThreadUnsubscribe {
request_id: RequestId,
params: ThreadUnsubscribeParams,
},
ThreadIncrementElicitation {
request_id: RequestId,
params: ThreadIncrementElicitationParams,
},
ThreadDecrementElicitation {
request_id: RequestId,
params: ThreadDecrementElicitationParams,
},
ThreadSetName {
request_id: RequestId,
params: ThreadSetNameParams,
},
ThreadGoalSet {
request_id: RequestId,
params: ThreadGoalSetParams,
},
ThreadGoalGet {
request_id: RequestId,
params: ThreadGoalGetParams,
},
ThreadGoalClear {
request_id: RequestId,
params: ThreadGoalClearParams,
},
ThreadMetadataUpdate {
request_id: RequestId,
params: ThreadMetadataUpdateParams,
},
ThreadSettingsUpdate {
request_id: RequestId,
params: ThreadSettingsUpdateParams,
},
ThreadMemoryModeSet {
request_id: RequestId,
params: ThreadMemoryModeSetParams,
},
MemoryReset {
request_id: RequestId,
params: Option<()>,
},
ThreadUnarchive {
request_id: RequestId,
params: ThreadUnarchiveParams,
},
ThreadCompactStart {
request_id: RequestId,
params: ThreadCompactStartParams,
},
ThreadShellCommand {
request_id: RequestId,
params: ThreadShellCommandParams,
},
ThreadApproveGuardianDeniedAction {
request_id: RequestId,
params: ThreadApproveGuardianDeniedActionParams,
},
ThreadBackgroundTerminalsClean {
request_id: RequestId,
params: ThreadBackgroundTerminalsCleanParams,
},
ThreadBackgroundTerminalsList {
request_id: RequestId,
params: ThreadBackgroundTerminalsListParams,
},
ThreadBackgroundTerminalsTerminate {
request_id: RequestId,
params: ThreadBackgroundTerminalsTerminateParams,
},
ThreadRollback {
request_id: RequestId,
params: ThreadRollbackParams,
},
ThreadList {
request_id: RequestId,
params: ThreadListParams,
},
ThreadSearch {
request_id: RequestId,
params: ThreadSearchParams,
},
ThreadSearchOccurrences {
request_id: RequestId,
params: ThreadSearchOccurrencesParams,
},
ThreadLoadedList {
request_id: RequestId,
params: ThreadLoadedListParams,
},
ThreadRead {
request_id: RequestId,
params: ThreadReadParams,
},
ThreadTurnsList {
request_id: RequestId,
params: ThreadTurnsListParams,
},
ThreadItemsList {
request_id: RequestId,
params: ThreadItemsListParams,
},
ThreadInjectItems {
request_id: RequestId,
params: ThreadInjectItemsParams,
},
SkillsList {
request_id: RequestId,
params: SkillsListParams,
},
SkillsExtraRootsSet {
request_id: RequestId,
params: SkillsExtraRootsSetParams,
},
HooksList {
request_id: RequestId,
params: HooksListParams,
},
MarketplaceAdd {
request_id: RequestId,
params: MarketplaceAddParams,
},
MarketplaceRemove {
request_id: RequestId,
params: MarketplaceRemoveParams,
},
MarketplaceUpgrade {
request_id: RequestId,
params: MarketplaceUpgradeParams,
},
PluginList {
request_id: RequestId,
params: PluginListParams,
},
PluginInstalled {
request_id: RequestId,
params: PluginInstalledParams,
},
PluginRead {
request_id: RequestId,
params: PluginReadParams,
},
PluginSkillRead {
request_id: RequestId,
params: PluginSkillReadParams,
},
PluginShareSave {
request_id: RequestId,
params: PluginShareSaveParams,
},
PluginShareUpdateTargets {
request_id: RequestId,
params: PluginShareUpdateTargetsParams,
},
PluginShareList {
request_id: RequestId,
params: PluginShareListParams,
},
PluginShareCheckout {
request_id: RequestId,
params: PluginShareCheckoutParams,
},
PluginShareDelete {
request_id: RequestId,
params: PluginShareDeleteParams,
},
AppsRead {
request_id: RequestId,
params: AppsReadParams,
},
AppsList {
request_id: RequestId,
params: AppsListParams,
},
AppsInstalled {
request_id: RequestId,
params: AppsInstalledParams,
},
FsReadFile {
request_id: RequestId,
params: FsReadFileParams,
},
FsWriteFile {
request_id: RequestId,
params: FsWriteFileParams,
},
FsCreateDirectory {
request_id: RequestId,
params: FsCreateDirectoryParams,
},
FsGetMetadata {
request_id: RequestId,
params: FsGetMetadataParams,
},
FsReadDirectory {
request_id: RequestId,
params: FsReadDirectoryParams,
},
FsRemove {
request_id: RequestId,
params: FsRemoveParams,
},
FsCopy {
request_id: RequestId,
params: FsCopyParams,
},
FsWatch {
request_id: RequestId,
params: FsWatchParams,
},
FsUnwatch {
request_id: RequestId,
params: FsUnwatchParams,
},
SkillsConfigWrite {
request_id: RequestId,
params: SkillsConfigWriteParams,
},
PluginInstall {
request_id: RequestId,
params: PluginInstallParams,
},
PluginUninstall {
request_id: RequestId,
params: PluginUninstallParams,
},
TurnStart {
request_id: RequestId,
params: TurnStartParams,
},
TurnSteer {
request_id: RequestId,
params: TurnSteerParams,
},
TurnInterrupt {
request_id: RequestId,
params: TurnInterruptParams,
},
ThreadRealtimeStart {
request_id: RequestId,
params: ThreadRealtimeStartParams,
},
ThreadRealtimeAppendAudio {
request_id: RequestId,
params: ThreadRealtimeAppendAudioParams,
},
ThreadRealtimeAppendText {
request_id: RequestId,
params: ThreadRealtimeAppendTextParams,
},
ThreadRealtimeAppendSpeech {
request_id: RequestId,
params: ThreadRealtimeAppendSpeechParams,
},
ThreadRealtimeStop {
request_id: RequestId,
params: ThreadRealtimeStopParams,
},
ThreadRealtimeListVoices {
request_id: RequestId,
params: ThreadRealtimeListVoicesParams,
},
ReviewStart {
request_id: RequestId,
params: ReviewStartParams,
},
ModelList {
request_id: RequestId,
params: ModelListParams,
},
ModelProviderCapabilitiesRead {
request_id: RequestId,
params: ModelProviderCapabilitiesReadParams,
},
ExperimentalFeatureList {
request_id: RequestId,
params: ExperimentalFeatureListParams,
},
PermissionProfileList {
request_id: RequestId,
params: PermissionProfileListParams,
},
ExperimentalFeatureEnablementSet {
request_id: RequestId,
params: ExperimentalFeatureEnablementSetParams,
},
RemoteControlEnable {
request_id: RequestId,
params: NullableRemoteControlEnableParams,
},
RemoteControlDisable {
request_id: RequestId,
params: NullableRemoteControlDisableParams,
},
RemoteControlStatusRead {
request_id: RequestId,
params: Option<()>,
},
RemoteControlPairingStart {
request_id: RequestId,
params: RemoteControlPairingStartParams,
},
RemoteControlPairingStatus {
request_id: RequestId,
params: RemoteControlPairingStatusParams,
},
RemoteControlClientsList {
request_id: RequestId,
params: RemoteControlClientsListParams,
},
RemoteControlClientsRevoke {
request_id: RequestId,
params: RemoteControlClientsRevokeParams,
},
CollaborationModeList {
request_id: RequestId,
params: CollaborationModeListParams,
},
MockExperimentalMethod {
request_id: RequestId,
params: MockExperimentalMethodParams,
},
EnvironmentAdd {
request_id: RequestId,
params: EnvironmentAddParams,
},
EnvironmentInfo {
request_id: RequestId,
params: EnvironmentInfoParams,
},
EnvironmentStatus {
request_id: RequestId,
params: EnvironmentStatusParams,
},
McpServerOauthLogin {
request_id: RequestId,
params: McpServerOauthLoginParams,
},
McpServerRefresh {
request_id: RequestId,
params: Option<()>,
},
McpServerStatusList {
request_id: RequestId,
params: ListMcpServerStatusParams,
},
McpResourceRead {
request_id: RequestId,
params: McpResourceReadParams,
},
McpServerToolCall {
request_id: RequestId,
params: McpServerToolCallParams,
},
WindowsSandboxSetupStart {
request_id: RequestId,
params: WindowsSandboxSetupStartParams,
},
WindowsSandboxReadiness {
request_id: RequestId,
params: Option<()>,
},
LoginAccount {
request_id: RequestId,
params: LoginAccountParams,
},
CancelLoginAccount {
request_id: RequestId,
params: CancelLoginAccountParams,
},
LogoutAccount {
request_id: RequestId,
params: Option<()>,
},
GetAccountRateLimits {
request_id: RequestId,
params: Option<()>,
},
ConsumeAccountRateLimitResetCredit {
request_id: RequestId,
params: ConsumeAccountRateLimitResetCreditParams,
},
GetAccountTokenUsage {
request_id: RequestId,
params: Option<()>,
},
GetWorkspaceMessages {
request_id: RequestId,
params: Option<()>,
},
SendAddCreditsNudgeEmail {
request_id: RequestId,
params: SendAddCreditsNudgeEmailParams,
},
FeedbackUpload {
request_id: RequestId,
params: FeedbackUploadParams,
},
OneOffCommandExec {
request_id: RequestId,
params: CommandExecParams,
},
CommandExecWrite {
request_id: RequestId,
params: CommandExecWriteParams,
},
CommandExecTerminate {
request_id: RequestId,
params: CommandExecTerminateParams,
},
CommandExecResize {
request_id: RequestId,
params: CommandExecResizeParams,
},
ProcessSpawn {
request_id: RequestId,
params: ProcessSpawnParams,
},
ProcessWriteStdin {
request_id: RequestId,
params: ProcessWriteStdinParams,
},
ProcessKill {
request_id: RequestId,
params: ProcessKillParams,
},
ProcessResizePty {
request_id: RequestId,
params: ProcessResizePtyParams,
},
ConfigRead {
request_id: RequestId,
params: ConfigReadParams,
},
ExternalAgentConfigDetect {
request_id: RequestId,
params: ExternalAgentConfigDetectParams,
},
ExternalAgentConfigImport {
request_id: RequestId,
params: ExternalAgentConfigImportParams,
},
ExternalAgentConfigImportHistoriesRead {
request_id: RequestId,
params: Option<()>,
},
ConfigValueWrite {
request_id: RequestId,
params: ConfigValueWriteParams,
},
ConfigBatchWrite {
request_id: RequestId,
params: ConfigBatchWriteParams,
},
ConfigRequirementsRead {
request_id: RequestId,
params: Option<()>,
},
GetAccount {
request_id: RequestId,
params: GetAccountParams,
},
GetConversationSummary {
request_id: RequestId,
params: GetConversationSummaryParams,
},
GitDiffToRemote {
request_id: RequestId,
params: GitDiffToRemoteParams,
},
GetAuthStatus {
request_id: RequestId,
params: GetAuthStatusParams,
},
FuzzyFileSearch {
request_id: RequestId,
params: FuzzyFileSearchParams,
},
FuzzyFileSearchSessionStart {
request_id: RequestId,
params: FuzzyFileSearchSessionStartParams,
},
FuzzyFileSearchSessionUpdate {
request_id: RequestId,
params: FuzzyFileSearchSessionUpdateParams,
},
FuzzyFileSearchSessionStop {
request_id: RequestId,
params: FuzzyFileSearchSessionStopParams,
},
}Expand description
Request from the client to the server.
Variants
Initialize
ThreadStart
NEW APIs
ThreadResume
ThreadFork
ThreadArchive
ThreadDelete
ThreadUnsubscribe
ThreadIncrementElicitation
Increment the thread-local out-of-band elicitation counter.
This is used by external helpers to pause timeout accounting while a user approval or other elicitation is pending outside the app-server request flow.
ThreadDecrementElicitation
Decrement the thread-local out-of-band elicitation counter.
When the count reaches zero, timeout accounting resumes for the thread.
ThreadSetName
ThreadGoalSet
ThreadGoalGet
ThreadGoalClear
ThreadMetadataUpdate
ThreadSettingsUpdate
ThreadMemoryModeSet
MemoryReset
ThreadUnarchive
ThreadCompactStart
ThreadShellCommand
ThreadApproveGuardianDeniedAction
ThreadBackgroundTerminalsClean
ThreadBackgroundTerminalsList
ThreadBackgroundTerminalsTerminate
ThreadRollback
ThreadList
ThreadSearch
ThreadSearchOccurrences
ThreadLoadedList
ThreadRead
ThreadTurnsList
ThreadItemsList
ThreadInjectItems
Append raw Responses API items to the thread history without starting a user turn.
SkillsList
SkillsExtraRootsSet
HooksList
MarketplaceAdd
MarketplaceRemove
MarketplaceUpgrade
PluginList
PluginInstalled
PluginRead
PluginSkillRead
AppsRead
AppsList
AppsInstalled
FsReadFile
FsWriteFile
FsCreateDirectory
FsGetMetadata
FsReadDirectory
FsRemove
FsCopy
FsWatch
FsUnwatch
SkillsConfigWrite
PluginInstall
PluginUninstall
TurnStart
TurnSteer
TurnInterrupt
ThreadRealtimeStart
ThreadRealtimeAppendAudio
ThreadRealtimeAppendText
ThreadRealtimeAppendSpeech
ThreadRealtimeStop
ThreadRealtimeListVoices
ReviewStart
ModelList
ModelProviderCapabilitiesRead
ExperimentalFeatureList
PermissionProfileList
ExperimentalFeatureEnablementSet
RemoteControlEnable
RemoteControlDisable
RemoteControlStatusRead
RemoteControlPairingStart
RemoteControlPairingStatus
RemoteControlClientsList
RemoteControlClientsRevoke
CollaborationModeList
Lists collaboration mode presets.
MockExperimentalMethod
Test-only method used to validate experimental gating.
EnvironmentAdd
Adds or replaces a remote environment by id for later selection.
EnvironmentInfo
Reads information from a configured execution environment.
EnvironmentStatus
Reads the current status of a configured execution environment.
McpServerOauthLogin
McpServerRefresh
McpServerStatusList
McpResourceRead
McpServerToolCall
WindowsSandboxSetupStart
WindowsSandboxReadiness
LoginAccount
CancelLoginAccount
LogoutAccount
GetAccountRateLimits
ConsumeAccountRateLimitResetCredit
GetAccountTokenUsage
GetWorkspaceMessages
SendAddCreditsNudgeEmail
FeedbackUpload
OneOffCommandExec
Execute a standalone command (argv vector) under the server’s sandbox.
CommandExecWrite
Write stdin bytes to a running command/exec session or close stdin.
CommandExecTerminate
Terminate a running command/exec session by client-supplied processId.
CommandExecResize
Resize a running PTY-backed command/exec session by client-supplied processId.
ProcessSpawn
Spawn a standalone process (argv vector) without a Codex sandbox.
ProcessWriteStdin
Write stdin bytes to a running process/spawn session or close stdin.
ProcessKill
Terminate a running process/spawn session by client-supplied processHandle.
ProcessResizePty
Resize a running PTY-backed process/spawn session by client-supplied processHandle.
ConfigRead
ExternalAgentConfigDetect
ExternalAgentConfigImport
ExternalAgentConfigImportHistoriesRead
ConfigValueWrite
ConfigBatchWrite
ConfigRequirementsRead
GetAccount
GetConversationSummary
DEPRECATED APIs below
GitDiffToRemote
GetAuthStatus
DEPRECATED in favor of GetAccount
FuzzyFileSearch
FuzzyFileSearchSessionStart
FuzzyFileSearchSessionUpdate
FuzzyFileSearchSessionStop
Implementations
Sourceimpl ClientRequest
impl ClientRequest
pub fn id(&self) -> &RequestId
pub fn method(&self) -> String
pub fn serialization_scope(&self) -> Option<ClientRequestSerializationScope>