pub enum ThreadItem {
Show 18 variants
UserMessage {
id: String,
client_id: Option<String>,
content: Vec<UserInput>,
},
HookPrompt {
id: String,
fragments: Vec<HookPromptFragment>,
},
AgentMessage {
id: String,
text: String,
phase: Option<MessagePhase>,
memory_citation: Option<MemoryCitation>,
},
Plan {
id: String,
text: String,
},
Reasoning {
id: String,
summary: Vec<String>,
content: Vec<String>,
},
CommandExecution {
id: String,
command: String,
cwd: LegacyAppPathString,
process_id: Option<String>,
source: CommandExecutionSource,
status: CommandExecutionStatus,
command_actions: Vec<CommandAction>,
aggregated_output: Option<String>,
exit_code: Option<i32>,
duration_ms: Option<i64>,
},
FileChange {
id: String,
changes: Vec<FileUpdateChange>,
status: PatchApplyStatus,
},
McpToolCall {
id: String,
server: String,
tool: String,
status: McpToolCallStatus,
arguments: Value,
app_context: Option<McpToolCallAppContext>,
mcp_app_resource_uri: Option<String>,
plugin_id: Option<String>,
result: Option<Box<McpToolCallResult>>,
error: Option<McpToolCallError>,
duration_ms: Option<i64>,
},
DynamicToolCall {
id: String,
namespace: Option<String>,
tool: String,
arguments: Value,
status: DynamicToolCallStatus,
content_items: Option<Vec<DynamicToolCallOutputContentItem>>,
success: Option<bool>,
duration_ms: Option<i64>,
},
CollabAgentToolCall {
id: String,
tool: CollabAgentTool,
status: CollabAgentToolCallStatus,
sender_thread_id: String,
receiver_thread_ids: Vec<String>,
prompt: Option<String>,
model: Option<String>,
reasoning_effort: Option<ReasoningEffort>,
agents_states: HashMap<String, CollabAgentState>,
},
SubAgentActivity {
id: String,
kind: SubAgentActivityKind,
agent_thread_id: String,
agent_path: String,
},
WebSearch(WebSearchItem),
ImageView {
id: String,
path: LegacyAppPathString,
},
Sleep(SleepItem),
ImageGeneration(ImageGenerationItem),
EnteredReviewMode {
id: String,
review: String,
},
ExitedReviewMode {
id: String,
review: String,
},
ContextCompaction {
id: String,
},
}Variants
UserMessage
HookPrompt
AgentMessage
Plan
EXPERIMENTAL - proposed plan item content. The completed plan item is
authoritative and may not match the concatenation of PlanDelta text.
Reasoning
CommandExecution
Fields

cwd: LegacyAppPathStringThe command’s working directory.

source: CommandExecutionSource
status: CommandExecutionStatus
command_actions: Vec<CommandAction>A best-effort parsing of the command to understand the action(s) it will perform. This returns a list of CommandAction objects because a single shell command may be composed of many commands piped together.
FileChange
McpToolCall
Fields

status: McpToolCallStatus
app_context: Option<McpToolCallAppContext>
result: Option<Box<McpToolCallResult>>
error: Option<McpToolCallError>DynamicToolCall
CollabAgentToolCall
Fields

tool: CollabAgentToolName of the collab tool that was invoked.

status: CollabAgentToolCallStatusCurrent status of the collab tool call.

receiver_thread_ids: Vec<String>Thread ID of the receiving agent, when applicable. In case of spawn operation, this corresponds to the newly spawned agent.

reasoning_effort: Option<ReasoningEffort>Reasoning effort requested for the spawned agent, when applicable.

agents_states: HashMap<String, CollabAgentState>Last known status of the target agents, when available.
SubAgentActivity
WebSearch(WebSearchItem)
ImageView
Sleep(SleepItem)
ImageGeneration(ImageGenerationItem)
EnteredReviewMode
ExitedReviewMode
ContextCompaction
Implementations