We do not do true JSON-RPC 2.0, as we neither send nor expect the “jsonrpc”: “2.0” field.
Structs
- JSONRPC
Error - A response to a request that indicates an error occurred.
- JSONRPC
Error Error - JSONRPC
Notification - A notification which does not expect a response.
- JSONRPC
Request - A request that expects a response.
- JSONRPC
Response - A successful (non-error) response to a request.
Enums
- JSONRPC
Message - Refers to any valid JSON-RPC object that can be decoded off the wire, or encoded to be sent.
- Request
Id