pub struct TurnStartParams {Show 20 fields
pub thread_id: String,
pub client_user_message_id: Option<String>,
pub input: Vec<UserInput>,
pub responsesapi_client_metadata: Option<HashMap<String, String>>,
pub additional_context: Option<HashMap<String, AdditionalContextEntry>>,
pub environments: Option<Vec<TurnEnvironmentParams>>,
pub cwd: Option<PathBuf>,
pub runtime_workspace_roots: Option<Vec<AbsolutePathBuf>>,
pub approval_policy: Option<AskForApproval>,
pub approvals_reviewer: Option<ApprovalsReviewer>,
pub sandbox_policy: Option<SandboxPolicy>,
pub permissions: Option<String>,
pub model: Option<String>,
pub service_tier: Option<Option<String>>,
pub effort: Option<ReasoningEffort>,
pub summary: Option<ReasoningSummary>,
pub personality: Option<Personality>,
pub output_schema: Option<Value>,
pub collaboration_mode: Option<CollaborationMode>,
pub multi_agent_mode: Option<MultiAgentMode>,
}Fields
thread_id: Stringclient_user_message_id: Option<String>input: Vec<UserInput>responsesapi_client_metadata: Option<HashMap<String, String>>Optional metadata to enrich Codex’s ResponsesAPI turn metadata.
Entries are flattened into the JSON string sent as
client_metadata["x-codex-turn-metadata"] on ResponsesAPI HTTP and websocket requests.
They are not sent as top-level ResponsesAPI client_metadata keys, and reserved keys
such as session_id, thread_id, turn_id, and window_id cannot be overridden.
additional_context: Option<HashMap<String, AdditionalContextEntry>>Optional client-provided context fragments keyed by an opaque source identifier.
environments: Option<Vec<TurnEnvironmentParams>>Optional environments for this turn and subsequent turns.
Omitted uses the thread sticky environments. Empty disables environment access for this turn. Non-empty selects the first environment as the current turn environment for this turn.
cwd: Option<PathBuf>Override the working directory for this turn and subsequent turns.
runtime_workspace_roots: Option<Vec<AbsolutePathBuf>>Replace the thread’s runtime workspace roots for this turn and subsequent turns. Paths must be absolute.
approval_policy: Option<AskForApproval>Override the approval policy for this turn and subsequent turns.
approvals_reviewer: Option<ApprovalsReviewer>Override where approval requests are routed for review on this turn and subsequent turns.
sandbox_policy: Option<SandboxPolicy>Override the sandbox policy for this turn and subsequent turns.
permissions: Option<String>Select a named permissions profile id for this turn and subsequent
turns. Cannot be combined with sandboxPolicy.
model: Option<String>Override the model for this turn and subsequent turns.
service_tier: Option<Option<String>>Override the service tier for this turn and subsequent turns.
effort: Option<ReasoningEffort>Override the reasoning effort for this turn and subsequent turns.
summary: Option<ReasoningSummary>Override the reasoning summary for this turn and subsequent turns.
personality: Option<Personality>Override the personality for this turn and subsequent turns.
output_schema: Option<Value>Optional JSON Schema used to constrain the final assistant message for this turn.
collaboration_mode: Option<CollaborationMode>EXPERIMENTAL - Set a pre-set collaboration mode. Takes precedence over model, reasoning_effort, and developer instructions if set.
For collaboration_mode.settings.developer_instructions, null means
“use the built-in instructions for the selected mode”.
multi_agent_mode: Option<MultiAgentMode>@deprecated Ignored. Use effort: "ultra" for proactive multi-agent behavior.