pub trait ExperimentalApi {
// Required method
fn experimental_reason(&self) -> Option<&'static str>;
}Expand description
Marker trait for protocol types that can signal experimental usage.
Required Methods
Sourcefn experimental_reason(&self) -> Option<&'static str>
fn experimental_reason(&self) -> Option<&'static str>
Returns a short reason identifier when an experimental method or field is
used, or None when the value is entirely stable.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".